==> plf-community-tomcat-standalone-4.0.1.zip: com/smartgwt/client/docs/Dragdrop.java <==

package com.smartgwt.client.docs;

/**
 * <h3>Drag and Drop</h3>
 * Dragging objects and dropping them onto other objects
 * @see com.smartgwt.client.widgets.grid.ListGrid#transferSelectedData
 * @see com.smartgwt.client.widgets.tile.TileGrid#transferSelectedData
 * @see com.smartgwt.client.widgets.Canvas#setDragTracker
 * @see com.smartgwt.client.widgets.Canvas#shouldDragScroll
 * @see com.smartgwt.client.widgets.Canvas#willAcceptDrop
 * @see com.smartgwt.client.widgets.Canvas#getHSnapPosition
 * @see com.smartgwt.client.widgets.Canvas#getVSnapPosition
 * @see com.smartgwt.client.widgets.Canvas#shouldSnapOnDrop
 * @see com.smartgwt.client.util.EventHandler#getDragRect
 * @see com.smartgwt.client.widgets.Canvas#getEventEdge
 * @see com.smartgwt.client.grid.GridRenderer#getSnapToCells
 * @see com.smartgwt.client.grid.GridRenderer#getSnapInsideBorder
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanDragRecordsOut
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanAcceptDroppedRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanReorderRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanReparentNodes
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getManyItemsImage
 * @see com.smartgwt.client.widgets.tile.TileGrid#getTileDragAppearance
 * @see com.smartgwt.client.widgets.Canvas#getCanDrag
 * @see com.smartgwt.client.widgets.Canvas#getDragStartDistance
 * @see com.smartgwt.client.widgets.Canvas#getDragIntersectStyle
 * @see com.smartgwt.client.widgets.Canvas#getCanDragReposition
 * @see com.smartgwt.client.widgets.Canvas#getDragRepositionCursor
 * @see com.smartgwt.client.widgets.Canvas#getCanDragResize
 * @see com.smartgwt.client.widgets.Canvas#getResizeFrom
 * @see com.smartgwt.client.widgets.Canvas#getEdgeMarginSize
 * @see com.smartgwt.client.widgets.Canvas#getEdgeCursorMap
 * @see com.smartgwt.client.widgets.Canvas#getKeepInParentRect
 * @see com.smartgwt.client.widgets.Canvas#getDragAppearance
 * @see com.smartgwt.client.widgets.Canvas#getDragType
 * @see com.smartgwt.client.widgets.Canvas#getDragTarget
 * @see com.smartgwt.client.widgets.Canvas#getShowDragShadow
 * @see com.smartgwt.client.widgets.Canvas#getDragOpacity
 * @see com.smartgwt.client.widgets.Canvas#getCanDrop
 * @see com.smartgwt.client.widgets.Canvas#getCanAcceptDrop
 * @see com.smartgwt.client.widgets.Canvas#getDropTypes
 * @see com.smartgwt.client.widgets.Canvas#getSnapToGrid
 * @see com.smartgwt.client.widgets.Canvas#getSnapResizeToGrid
 * @see com.smartgwt.client.widgets.Canvas#getChildrenSnapToGrid
 * @see com.smartgwt.client.widgets.Canvas#getChildrenSnapResizeToGrid
 * @see com.smartgwt.client.widgets.Canvas#getSnapHGap
 * @see com.smartgwt.client.widgets.Canvas#getSnapVGap
 * @see com.smartgwt.client.widgets.Canvas#getSnapHDirection
 * @see com.smartgwt.client.widgets.Canvas#getSnapVDirection
 * @see com.smartgwt.client.widgets.Canvas#getSnapAxis
 * @see com.smartgwt.client.widgets.Canvas#getSnapOnDrop
 * @see com.smartgwt.client.widgets.Window#getKeepInParentRect
 * @see com.smartgwt.client.widgets.layout.Layout#getCanDropComponents
 * @see com.smartgwt.client.widgets.layout.Layout#getDropLineThickness
 * @see com.smartgwt.client.widgets.layout.Layout#getShowDragPlaceHolder
 * @see com.smartgwt.client.widgets.layout.Layout#getPlaceHolderProperties
 * @see com.smartgwt.client.widgets.layout.Layout#getPlaceHolderDefaults
 * @see com.smartgwt.client.types.DragAppearance
 * @see com.smartgwt.client.types.DragIntersectStyle
 */
public interface Dragdrop {
}

==> plf-community-tomcat-standalone-4.2.0.zip: com/smartgwt/client/docs/Dragdrop.java <==

package com.smartgwt.client.docs;

/**
 * <h3>Drag and Drop</h3>
 * Dragging objects and dropping them onto other objects
 * @see com.smartgwt.client.widgets.layout.PortalLayout#setPortletDropTypes
 * @see com.smartgwt.client.widgets.layout.PortalLayout#willAcceptPortletDrop
 * @see com.smartgwt.client.widgets.Canvas#setDragTracker
 * @see com.smartgwt.client.widgets.Canvas#shouldDragScroll
 * @see com.smartgwt.client.widgets.Canvas#willAcceptDrop
 * @see com.smartgwt.client.widgets.Canvas#getHSnapPosition
 * @see com.smartgwt.client.widgets.Canvas#getVSnapPosition
 * @see com.smartgwt.client.widgets.Canvas#shouldSnapOnDrop
 * @see com.smartgwt.client.widgets.grid.ListGrid#transferSelectedData
 * @see com.smartgwt.client.widgets.tile.TileGrid#transferSelectedData
 * @see com.smartgwt.client.util.EventHandler#getDragRect
 * @see com.smartgwt.client.widgets.Canvas#getEventEdge
 * @see com.smartgwt.client.widgets.Window#getKeepInParentRect
 * @see com.smartgwt.client.widgets.layout.Portlet#getDragType
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getPortletDropTypes
 * @see com.smartgwt.client.widgets.layout.PortalLayout#getDropTypes
 * @see com.smartgwt.client.widgets.tab.TabSet#getCanReorderTabs
 * @see com.smartgwt.client.widgets.Canvas#getCanDrag
 * @see com.smartgwt.client.widgets.Canvas#getDragStartDistance
 * @see com.smartgwt.client.widgets.Canvas#getDragIntersectStyle
 * @see com.smartgwt.client.widgets.Canvas#getCanDragReposition
 * @see com.smartgwt.client.widgets.Canvas#getDragRepositionCursor
 * @see com.smartgwt.client.widgets.Canvas#getCanDragResize
 * @see com.smartgwt.client.widgets.Canvas#getResizeFrom
 * @see com.smartgwt.client.widgets.Canvas#getEdgeMarginSize
 * @see com.smartgwt.client.widgets.Canvas#getEdgeCursorMap
 * @see com.smartgwt.client.widgets.Canvas#getKeepInParentRect
 * @see com.smartgwt.client.widgets.Canvas#getDragAppearance
 * @see com.smartgwt.client.widgets.Canvas#getDragResizeAppearance
 * @see com.smartgwt.client.widgets.Canvas#getDragRepositionAppearance
 * @see com.smartgwt.client.widgets.Canvas#getDragType
 * @see com.smartgwt.client.widgets.Canvas#getDragTarget
 * @see com.smartgwt.client.widgets.Canvas#getShowDragShadow
 * @see com.smartgwt.client.widgets.Canvas#getDragOpacity
 * @see com.smartgwt.client.widgets.Canvas#getCanDrop
 * @see com.smartgwt.client.widgets.Canvas#getCanAcceptDrop
 * @see com.smartgwt.client.widgets.Canvas#getDropTypes
 * @see com.smartgwt.client.widgets.Canvas#getSnapToGrid
 * @see com.smartgwt.client.widgets.Canvas#getSnapResizeToGrid
 * @see com.smartgwt.client.widgets.Canvas#getChildrenSnapToGrid
 * @see com.smartgwt.client.widgets.Canvas#getChildrenSnapResizeToGrid
 * @see com.smartgwt.client.widgets.Canvas#getSnapHGap
 * @see com.smartgwt.client.widgets.Canvas#getSnapVGap
 * @see com.smartgwt.client.widgets.Canvas#getSnapHDirection
 * @see com.smartgwt.client.widgets.Canvas#getSnapVDirection
 * @see com.smartgwt.client.widgets.Canvas#getSnapAxis
 * @see com.smartgwt.client.widgets.Canvas#getSnapOnDrop
 * @see com.smartgwt.client.grid.GridRenderer#getSnapToCells
 * @see com.smartgwt.client.grid.GridRenderer#getSnapInsideBorder
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCanDropInEmptyArea
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanDragRecordsOut
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanAcceptDroppedRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanReorderRecords
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCanReparentNodes
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getManyItemsImage
 * @see com.smartgwt.client.widgets.tile.TileGrid#getTileDragAppearance
 * @see com.smartgwt.client.widgets.drawing.DrawItem#getDragStartDistance
 * @see com.smartgwt.client.widgets.layout.Layout#getCanDropComponents
 * @see com.smartgwt.client.widgets.layout.Layout#getDropLineThickness
 * @see com.smartgwt.client.widgets.layout.Layout#getShowDropLines
 * @see com.smartgwt.client.widgets.layout.Layout#getShowDragPlaceHolder
 * @see com.smartgwt.client.widgets.layout.Layout#getPlaceHolderProperties
 * @see com.smartgwt.client.widgets.layout.Layout#getPlaceHolderDefaults
 * @see com.smartgwt.client.widgets.layout.SectionStack#getCanDropComponents
 * @see com.smartgwt.client.types.DragAppearance
 * @see com.smartgwt.client.types.DragIntersectStyle
 */
public interface Dragdrop {
}
